==> lincity-ng_2.12.0.orig.tar.gz: lincity-ng-lincity-ng-2.12.0/src/gui/TooltipManager.hpp <==
/*
Copyright (C) 2005 Matthias Braun <matze@braunis.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @author Matthias Braun
 * @file TooltipManager.hpp
 */

#ifndef __TOOLTIPMANAGER_HPP__
#define __TOOLTIPMANAGER_HPP__

#include <SDL.h>   // for Uint32
#include <string>         // for string
#include <vector>         // for vector

#include "Child.hpp"      // for Child, Childs
#include "Component.hpp"  // for Component
#include "Event.hpp"      // for Event

class Vector2;
class XmlReader;

static const Uint32 TOOLTIP_TIME = 500;

/**
 * @class TooltipManager
 */
class TooltipManager : public Component
{
public:
    TooltipManager();
    ~TooltipManager();

    void parse(XmlReader& reader);

    void resize(float width, float height);
    void event(const Event& event);
    bool opaque(const Vector2& pos) const;

    void showTooltip(const std::string& text, const Vector2& pos);

private:
    Child& comp_tooltip()
    {
        return childs[0];
    }
};

/// global TooltipManager instance
extern TooltipManager* tooltipManager;

#endif


/** @file gui/TooltipManager.hpp */

==> lincity-ng_2.14.2.orig.tar.gz: lincity-ng-lincity-ng-2.14.2/src/gui/TooltipManager.hpp <==
/*
Copyright (C) 2005 Matthias Braun <matze@braunis.de>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 * @author Matthias Braun
 * @file TooltipManager.hpp
 */

#ifndef __TOOLTIPMANAGER_HPP__
#define __TOOLTIPMANAGER_HPP__

#include <SDL.h>          // for Uint32
#include <string>         // for string

#include "Child.hpp"      // for Childs, Child (ptr only)
#include "Component.hpp"  // for Component

class Vector2;
class XmlReader;

static const Uint32 TOOLTIP_TIME = 500;

/**
 * @class TooltipManager
 */
class TooltipManager : public Component
{
public:
    TooltipManager();
    ~TooltipManager();

    void parse(XmlReader& reader);

    void resize(float width, float height);
    void event(const Event& event);
    bool opaque(const Vector2& pos) const;

    void showTooltip(const std::string& text, const Vector2& pos);

private:
    Child& comp_tooltip()
    {
        return childs[0];
    }
};

/// global TooltipManager instance
extern TooltipManager* tooltipManager;

#endif


/** @file gui/TooltipManager.hpp */
